.. -*- mode: rst -*-

|AzurePipelines|_ |ReadTheDocs|_ |CodeCov|_ |CodeStyleBlack|_ |CodeFactor|_ |LGTM|_

.. |AzurePipelines| image:: https://dev.azure.com/rvanveen133/sklvq/_apis/build/status/rickvanveen.sklvq?branchName=master
.. _AzurePipelines: https://dev.azure.com/rvanveen133/sklvq/

.. |ReadTheDocs| image:: https://readthedocs.org/projects/sklvq/badge/?version=stable
.. _ReadTheDocs: https://sklvq.readthedocs.io/en/latest/?badge=stable

.. |CodeCov| image:: https://codecov.io/gh/rickvanveen/sklvq/branch/master/graph/badge.svg
.. _CodeCov: https://codecov.io/gh/rickvanveen/sklvq

.. |CodeStyleBlack| image:: https://img.shields.io/badge/code%20style-black-000000.svg
.. _CodeStyleBlack: https://github.com/psf/black

.. |CodeFactor| image:: https://www.codefactor.io/repository/github/rickvanveen/sklvq/badge/master
.. _CodeFactor: https://www.codefactor.io/repository/github/rickvanveen/sklvq/

.. |LGTM| image:: https://img.shields.io/lgtm/grade/python/g/rickvanveen/sklvq.svg?logo=lgtm&logoWidth=18)
.. _LGTM: https://lgtm.com/projects/g/rickvanveen/sklvq/context:python

sklvq - A collection of expandable Learning Vector Quantization algorithms
==========================================================================

Documentation with install instruction and examples can be found here: https://sklvq.readthedocs.io/en/latest/

If you find any bugs or have any other suggestions on how to improve the code then please use the issue tracker on
github (https://github.com/rickvanveen/sklvq/issues).
